@@ -5,7 +5,7 @@ use warnings;
 
 use RxPerl::Operators::Creation ':all';
 use RxPerl::Operators::Pipeable ':all';
-use RxPerl::Functions 'last_value_from', 'first_value_from';
+use RxPerl::Functions ':all';
 
 use Exporter 'import';
 our @EXPORT_OK = (
@@ -15,7 +15,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.16.0";
+our $VERSION = "v6.17.0";
 
 1;
 __END__
@@ -61,7 +61,7 @@ The documentation in this POD applies to all three adapter modules as well.
 This module is an implementation of L<Reactive Extensions|http://reactivex.io/> in Perl. It replicates the
 behavior of L<rxjs 6|https://www.npmjs.com/package/rxjs> which is the JavaScript implementation of ReactiveX.
 
-Currently 67 of the 100+ operators in rxjs are implemented in this module.
+Currently 73 of the 100+ operators in rxjs are implemented in this module.
 
 =head1 EXPORTABLE FUNCTIONS
 
@@ -209,6 +209,18 @@ Similar to: L</rx_from_event>.
 Observables may emit at most one value per event, however L<Mojo::EventEmitter>'s are able to emit
 more. So this function serves to pack all of them in an arrayref, and emit that as a single value instead.
 
+=item rx_generate
+
+L<https://rxjs.dev/api/index/function/generate>
+
+    # 2, 5, 10, 17, 26
+    rx_generate(
+        1,
+        sub ($x) { $x <= 5 }, # could also use $_
+        sub ($x) { $x + 1 }, # could also use $_
+        sub ($x) { $x ** 2 + 1 }, # optional, and could also use $_ here
+    )->subscribe($observer);
+
 =item rx_interval
 
 L<https://rxjs.dev/api/index/function/interval>
@@ -256,6 +268,18 @@ L<https://rxjs.dev/api/index/function/of>
     # 10, 20, 30, complete
     rx_of(10, 20, 30)->subscribe($observer);
 
+=item rx_on_error_resume_next
+
+L<https://rxjs.dev/api/index/function/onErrorResumeNext>
+
+    # 1, 2, 3, 10, 20, 30, complete
+    rx_on_error_resume_next(
+        rx_of(1, 2, 3)->pipe( op_concat_with(rx_throw_error('foo')) ),
+        rx_throw_error('bar'),
+        rx_of(10, 20, 30),
+        rx_throw_error('baz'),
+    )->subscribe($observer);
+
 =item rx_partition
 
 L<https://rxjs.dev/api/index/function/partition>
@@ -712,10 +736,33 @@ L<https://rxjs.dev/api/operators/mergeMap>
         }),
     )->subscribe($observer);
 
+=item op_merge_with
+
+L<https://rxjs.dev/api/operators/mergeWith>
+
+    # 0, 0, 1, 1, 2, 3, 2, 4, 3, ...
+    rx_interval(0.7)->pipe(
+        rx_merge_with( rx_interval(1) ),
+    )->subscribe($observer);
+
 =item op_multicast
 
 L<https://rxjs.dev/api/operators/multicast>
 
+=item op_on_error_resume_next_with
+
+L<https://rxjs.dev/api/index/function/onErrorResumeNextWith>
+
+    # 1, 2, 3, 10, 20, 30, complete
+    rx_of(1, 2, 3)->pipe(
+        op_concat_with( rx_throw_error('foo') ),
+        op_on_error_resume_next_with(
+            rx_throw_error('bar'),
+            rx_of(10, 20, 30),
+            rx_throw_error('baz'),
+        ),
+    )->subscribe($observer);
+
 =item op_pairwise
 
 L<https://rxjs.dev/api/operators/pairwise>
@@ -829,6 +876,15 @@ L<https://rxjs.dev/api/operators/skipUntil>
         op_skip_until( rx_timer(3.5) ),
     )->subscribe($observer);
 
+=item op_skip_while
+
+L<https://rxjs.dev/api/operators/skipWhile>
+
+    # 5, 3, 7, 1, complete
+    rx_of(1, 3, 5, 3, 7, 1)->pipe(
+        op_skip_while(sub ($v, $idx) { $v < 4 }), # could use $_ here
+    )->subscribe($observer);
+
 =item op_start_with
 
 L<https://rxjs.dev/api/operators/startWith>
@@ -917,6 +973,19 @@ L<https://rxjs.dev/api/operators/withLatestFrom>
         op_with_latest_from(rx_interval(0.7)),
     )->subscribe($observer);
 
+=item op_zip_with
+
+L<https://rxjs.dev/api/operators/zipWith>
+
+    # [0, 0, 0], [1, 1, 1], [2, 2, 2], complete
+    rx_interval(0.7)->pipe(
+        op_take(3),
+        op_zip_with(
+            rx_interval(1),
+            rx_interval(2),
+        ),
+    )->subscribe($observer);
+
 =back
 
 =head2 PROMISE FUNCTIONS
@@ -960,6 +1029,16 @@ promise is rejected.
 
 =back
 
+=head2 OTHER FUNCTIONS
+
+=over
+
+=item is_observable
+
+Returns true if the argument passed to it is an RxPerl Observable.
+
+=back
+
 =head1 OBSERVABLE METHODS
 
 =over
