@@ -6,13 +6,15 @@ use warnings;
 require RxPerl::Operators::Pipeable;
 
 use Carp 'croak';
+use Scalar::Util 'blessed';
 
 use Exporter 'import';
 our @EXPORT_OK = qw/
-    last_value_from first_value_from
+    last_value_from first_value_from is_observable
 /;
+our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.16.0";
+our $VERSION = "v6.17.0";
 
 sub _promise_class {
     my $fn = (caller(1))[3];
@@ -70,4 +72,10 @@ sub first_value_from {
     );
 }
 
-1;
\ No newline at end of file
+sub is_observable {
+    my ($thing) = @_;
+
+    return !!(blessed($thing) && $thing->isa('RxPerl::Observable'));
+}
+
+1;
