@@ -16,12 +16,12 @@ use List::Util 'first';
 use Exporter 'import';
 our @EXPORT_OK = qw/
     rx_behavior_subject rx_combine_latest rx_concat rx_defer rx_EMPTY rx_fork_join rx_from rx_from_event
-    rx_from_event_array rx_interval rx_merge rx_NEVER rx_observable rx_of rx_partition rx_race rx_range
-    rx_replay_subject rx_subject rx_throw_error rx_timer rx_zip
+    rx_from_event_array rx_generate rx_interval rx_merge rx_NEVER rx_observable rx_of rx_on_error_resume_next
+    rx_partition rx_race rx_range rx_replay_subject rx_subject rx_throw_error rx_timer rx_zip
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.16.0";
+our $VERSION = "v6.17.0";
 
 sub rx_observable;
 
@@ -100,7 +100,7 @@ sub _rx_concat_helper {
 }
 
 sub rx_concat {
-    my (@sources) = @_;
+    my @sources = @_;
 
     return rx_observable->new(sub {
         my ($subscriber) = @_;
@@ -322,6 +322,43 @@ sub rx_from_event_array {
     });
 }
 
+sub rx_generate {
+    my ($initial, $condition, $iterate, $result_selector) = @_;
+
+    return rx_observable->new(sub {
+        my ($subscriber) = @_;
+
+        my $must_finish = 0;
+
+        $subscriber->subscription->add(sub { $must_finish = 1 });
+
+        my $x = $initial;
+        while (1) {
+            ! $must_finish or last;
+            my $cond; my $ok = eval { local $_ = $x; $cond = $condition->($x); 1 };
+            if (! $ok) {
+                $subscriber->{error}->($@) if defined $subscriber->{error};
+                last;
+            }
+            if (! $cond) {
+                $subscriber->{complete}->() if defined $subscriber->{complete};
+                last;
+            }
+            my $output_val; $ok = eval { local $_ = $x; $output_val = $result_selector ? $result_selector->($x) : $x; 1 };
+            if (! $ok) {
+                $subscriber->{error}->($@) if defined $subscriber->{error};
+                last;
+            }
+            $subscriber->{next}->($output_val) if defined $subscriber->{next};
+            $ok = eval { local $_ = $x; $x = $iterate->($x); 1 };
+            if (! $ok) {
+                $subscriber->{error}->($@) if defined $subscriber->{error};
+                last;
+            }
+        }
+    });
+}
+
 sub rx_interval {
     my ($after) = @_;
 
@@ -410,6 +447,49 @@ sub rx_of {
     });
 }
 
+sub _rx_on_error_resume_next_helper {
+    my ($sources, $subscriber, $active) = @_;
+
+    if (! @$sources) {
+        $subscriber->{complete}->() if defined $subscriber->{complete};
+        return;
+    }
+
+    my $source = shift @$sources;
+    my $own_subscription = RxPerl::Subscription->new;
+    my $own_subscriber = {
+        new_subscription => $own_subscription,
+        next             => $subscriber->{next},
+        error            => sub {
+            _rx_on_error_resume_next_helper($sources, $subscriber, $active);
+        },
+        complete         => sub {
+            _rx_on_error_resume_next_helper($sources, $subscriber, $active);
+        },
+    };
+    @$active = ($own_subscription);
+    $source->subscribe($own_subscriber);
+}
+
+sub rx_on_error_resume_next {
+    my @sources = @_;
+
+    return rx_observable->new(sub {
+        my ($subscriber) = @_;
+
+        my @sources = @sources;
+
+        my @active;
+        $subscriber->subscription->add(
+            \@active, sub { undef @sources },
+        );
+
+        _rx_on_error_resume_next_helper(\@sources, $subscriber, \@active);
+
+        return;
+    });
+}
+
 sub rx_partition {
     my ($source, $predicate) = @_;
 
