@@ -3,7 +3,8 @@ use strict;
 use warnings;
 
 use RxPerl::Operators::Creation qw/
-    rx_observable rx_subject rx_concat rx_of rx_interval rx_combine_latest rx_concat rx_throw_error
+    rx_observable rx_subject rx_concat rx_of rx_interval rx_combine_latest rx_concat rx_throw_error rx_zip
+    rx_merge rx_on_error_resume_next
 /;
 use RxPerl::ConnectableObservable;
 use RxPerl::Utils qw/ get_timer_subs /;
@@ -17,13 +18,14 @@ our @EXPORT_OK = qw/
     op_audit_time op_buffer op_buffer_count op_buffer_time op_catch_error op_combine_latest_with op_concat_map
     op_concat_with op_count op_debounce_time op_default_if_empty op_delay op_distinct_until_changed
     op_distinct_until_key_changed op_element_at op_end_with op_every op_exhaust_map op_filter op_finalize op_first
-    op_ignore_elements op_map op_map_to op_merge_map op_multicast op_pairwise op_pluck op_reduce op_ref_count op_repeat
-    op_retry op_sample_time op_scan op_share op_skip op_skip_until op_start_with op_switch_map op_take op_take_until
-    op_take_while op_tap op_throttle_time op_with_latest_from
+    op_ignore_elements op_map op_map_to op_merge_map op_merge_with op_multicast op_on_error_resume_next_with op_pairwise
+    op_pluck op_reduce op_ref_count op_repeat op_retry op_sample_time op_scan op_share op_skip op_skip_until
+    op_skip_while op_start_with op_switch_map op_take op_take_until op_take_while op_tap op_throttle_time
+    op_with_latest_from op_zip_with
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.16.0";
+our $VERSION = "v6.17.0";
 
 sub op_audit_time {
     my ($duration) = @_;
@@ -877,6 +879,19 @@ sub op_merge_map {
     };
 }
 
+sub op_merge_with {
+    my @other_sources = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_merge(
+            $source,
+            @other_sources,
+        );
+    };
+}
+
 sub op_multicast {
     my ($subject_factory) = @_;
 
@@ -887,6 +902,19 @@ sub op_multicast {
     };
 }
 
+sub op_on_error_resume_next_with {
+    my @other_sources = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_on_error_resume_next(
+            $source,
+            @other_sources,
+        );
+    };
+}
+
 sub op_pairwise {
     return sub {
         my ($source) = @_;
@@ -1299,6 +1327,50 @@ sub op_skip_until {
     };
 }
 
+sub op_skip_while {
+    my ($predicate) = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my $finished_skipping = 0;
+
+            my $idx = 0;
+            my $own_subscriber = {
+                %$subscriber,
+                next => sub {
+                    my ($v) = @_;
+
+                    my $should_display;
+                    if ($finished_skipping) {
+                        $should_display = 1;
+                    } else {
+                        my $satisfies_predicate;
+                        my $ok = eval { local $_ = $v; $satisfies_predicate = $predicate->($v, $idx++); 1 };
+                        $ok or do {
+                            $subscriber->{error}->($@) if defined $subscriber->{error};
+                            return;
+                        };
+                        if (! $satisfies_predicate) {
+                            $finished_skipping = 1;
+                            $should_display = 1;
+                        }
+                    }
+
+                    $subscriber->{next}->(@_) if $should_display and defined $subscriber->{next};
+                }
+            };
+
+            $source->subscribe($own_subscriber);
+
+            return;
+        });
+    };
+}
+
 sub op_start_with {
     my (@values) = @_;
 
@@ -1588,6 +1660,19 @@ sub op_with_latest_from {
     };
 }
 
+sub op_zip_with {
+    my @other_sources = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_zip(
+            $source,
+            @other_sources,
+        );
+    };
+}
+
 sub _eqq {
     my ($x, $y) = @_;
 
